@@ -15,7 +15,7 @@ my $xzsufx =	'.tar.xz';
 
 use POSIX qw(strftime);
 use Getopt::Long;
-use strict vars;
+use strict 'vars';
 use warnings;
 
 # check environment
