@@ -401,8 +401,9 @@ enum { SSL_min_security_level = 2 };
 # endif /* OpenSSL too old */
 #endif /* USING_WOLFSSL */
 
-/* workaround for EVP_MD_fetch API - missing on wolfSSL and LibreSSL */
-#if defined(USING_WOLFSSL) || defined(LIBRESSL_VERSION_NUMBER)
+/* workaround for EVP_MD_fetch API - missing on wolfSSL and LibreSSL, both 
+ * claim 1.x or 2.x OpenSSL versions, so make our lives easy: */
+#if OPENSSL_VERSION_NUMBER < 0x30000000L
 # define EVP_MD_fetch(x, digest, y) (EVP_get_digestbyname(digest))
 # define EVP_MD_free(x) /* NOOP */
 # define fm_EVP_MD_const const // compatibility const EVP_MD* from EVP_get_digestbyname()
@@ -486,7 +487,7 @@ int SockRead(int sock, char *buf, int len)
 #endif
 
     if (--len < 1)
-	return(-1);
+	return -1;
     do {
 	/* 
 	 * The reason for these gymnastics is that we want two things:
@@ -565,13 +566,14 @@ int SockRead(int sock, char *buf, int len)
 	else
 #endif /* SSL_ENABLE */
 	{
-
+	    if (sock < 0)
+		return -1;
 	    if ((n = fm_peek(sock, bp, len)) <= 0)
-		return (-1);
+		return -1;
 	    if ((newline = (char *)memchr(bp, '\n', n)) != NULL)
 		n = newline - bp + 1;
 	    if ((n = fm_read(sock, bp, n)) == -1)
-		return(-1);
+		return -1;
 	}
 	bp += n;
 	len -= n;
@@ -615,11 +617,11 @@ int SockPeek(int sock)
 	}
 	else
 #endif /* SSL_ENABLE */
-	    n = fm_peek(sock, &ch, 1);
+	    n = sock >= 0 ? fm_peek(sock, &ch, 1) : -1;
 	if (n == -1)
 		return -1;
 
-    return(ch);
+    return ch;
 }
 
 #ifdef SSL_ENABLE
@@ -712,7 +714,7 @@ static int SSL_verify_callback(int ok_return, X509_STORE_CTX *ctx, const int str
 			/* Possible truncation. In this case, this is a DNS name, so this
 			 * is really bad. We do not tolerate this even in the non-strict case. */
 			report(stderr, GT_("Bad certificate: Subject CommonName too long!\n"));
-			return (0);
+			return 0;
 		}
 		if ((size_t)i > strlen(buf)) {
 			/* Name contains embedded NUL characters, so we complain. This is likely
@@ -776,14 +778,14 @@ static int SSL_verify_callback(int ok_return, X509_STORE_CTX *ctx, const int str
 				}
 			} else if (ok_return) {
 				report(stderr, GT_("Server name not set, could not verify certificate!\n"));
-				if (strict) return (0);
+				if (strict) return 0;
 			}
 		} else {
 			if (outlevel >= O_VERBOSE)
 				report(stdout, GT_("Unknown Server CommonName\n"));
 			if (ok_return && strict) {
 				report(stderr, GT_("Server name not specified in certificate!\n"));
-				return (0);
+				return 0;
 			}
 		}
 		/* Print the finger print. Note that on errors, we might print it more than once
@@ -914,7 +916,7 @@ int check_sslfp(const X509 *x509_cert, char *text, size_t textsize, int *retFlag
                 if (esz >= te - tp)
                 {
                         report(stderr, GT_("Digest text buffer too small!\n"));
-                        return (0);
+                        return 0;
                 }
                 tp += esz;
         }
@@ -922,7 +924,7 @@ int check_sslfp(const X509 *x509_cert, char *text, size_t textsize, int *retFlag
 		report(stdout, GT_("%s fingerprint is: {%s}%s\n"), _server_label, dig, text);
 		fp_printed = true;
 	}
-        if (_check_digest != NULL)
+        if (_check_digest && expected_digest)
         {
                 if (0 == strcmp(expected_digest, "*")) {
 			if (!fp_printed) {
@@ -939,7 +941,7 @@ int check_sslfp(const X509 *x509_cert, char *text, size_t textsize, int *retFlag
                 {
                         report(stderr, GT_("%s fingerprint ({%s}%s) does not match expected %s!\n"), _server_label, dig, text, expected_digest);
 			xfree(dig);
-                        return (0);
+                        return 0;
                 }
         } /* if (_check_digest != NULL) */
         *retFlag = 0;
@@ -1147,7 +1149,7 @@ int SSLOpen(int sock, char *mycert, char *mykey, const char *myproto, int certck
 
 	if( sock < 0 || (unsigned)sock > FD_SETSIZE ) {
 		report(stderr, GT_("File descriptor out of range for SSL") );
-		return( -1 );
+		return  -1 ;
 	}
 
 	/* Make sure a connection referring to an older context is not left */
@@ -1170,7 +1172,7 @@ int SSLOpen(int sock, char *mycert, char *mykey, const char *myproto, int certck
 		    report(stderr, GT_("Note that some distributions disable older protocol versions in weird non-standard ways. Try a newer protocol version.\n"));
 		}
 #endif
-		return(-1);
+		return -1;
 	}
 
 	{	// CIPHER LISTS for SSL and TLS <= 1.2
@@ -1312,7 +1314,7 @@ sslopen_bailout:
 		ERR_print_errors_fp(stderr);
 		SSL_CTX_free(_ctx[sock]);
 		_ctx[sock] = NULL;
-		return(-1);
+		return -1;
 	}
 	
 	/* This static is for the verify callback */
@@ -1348,8 +1350,7 @@ sslopen_bailout:
 		 * https://github.com/wolfSSL/wolfssl/issues/4592 */
 		int r = wolfSSL_check_domain_name(_ssl_context[sock], servercname);
 		if (WOLFSSL_SUCCESS != r) {
-			report(stderr, GT_("fetchmail: sock %d: wolfSSL_check_domain_name(%#p, \"%s\") returned %d, trying to continue\n"),
-					sock, _ssl_context[sock], servercname, r);
+			report(stderr, xstrdup(GT_("fetchmail: sock %d: wolfSSL_check_domain_name(%p, \"%s\") returned %d, trying to continue\n")), sock, _ssl_context[sock], servercname, r);
 		}
 	}
 #else
@@ -1460,7 +1461,7 @@ sslopen_bailout:
 			}
 		}
 		fm_SSLCleanup(sock);
-		return(-1);
+		return -1;
 	}
 
 	if (outlevel >= O_VERBOSE) {
@@ -1497,7 +1498,7 @@ sslopen_bailout:
 		report(stderr, GT_("Warning: the connection is insecure, continuing anyways. (Better use --sslcertck!)\n"));
 	}
 
-	return(0);
+	return 0;
 }
 #endif
 
@@ -1512,5 +1513,5 @@ int SockClose(int sock)
 #endif
 
     /* if there's an error closing at this point, not much we can do */
-    return(fm_close(sock));	/* this is guarded */
+    return fm_close(sock);	/* this is guarded */
 }
